# mypy-boto3-codestar

Type annotations for
[boto3.CodeStar 1.10.44](https://boto3.amazonaws.com/v1/documentation/api/1.10.44/reference/services/codestar.html#CodeStar) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

More information can be found [here](https://vemel.github.io/mypy_boto3/).

- [mypy-boto3-codestar](#mypy-boto3-codestar)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
    - [Code auto-complete](#code-auto-complete)
  - [How it works](#how-it-works)

## How to use

### Type checking

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `CodeStar` service.

```bash
python -m pip install boto3-stubs[mypy-boto3-codestar]
```

Use `boto3` with `mypy_boto3` in your project and enjoy type checking and auto-complete.

```python
import boto3

from mypy_boto3 import codestar
# alternative import if you do not want to install mypy_boto3 package
# import mypy_boto3_codestar as codestar

# Use this client as usual, now mypy can check if your code is valid.
# Check if your IDE supports function overloads,
# you probably do not need explicit type annotations
# client = boto3.client("codestar")
client: codestar.CodeStarClient = boto3.client("codestar")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: codestar.CodeStarClient = session.client("codestar")


# Paginators need type annotation on creation
list_projects_paginator: codestar.ListProjectsPaginator = client.get_paginator("list_projects")
list_resources_paginator: codestar.ListResourcesPaginator = client.get_paginator("list_resources")
list_team_members_paginator: codestar.ListTeamMembersPaginator = client.get_paginator("list_team_members")
list_user_profiles_paginator: codestar.ListUserProfilesPaginator = client.get_paginator("list_user_profiles")
```

## How it works

Fully automated [builder](https://github.com/vemel/mypy_boto3) carefully generates
type annotations for each service, patiently waiting for `boto3` updates. It delivers
a drop-in type annotations for you and makes sure that:

- All available `boto3` services are covered.
- Each public class and method of every `boto3` service gets valid type annotations
  extracted from the documentation (blame `botocore` docs if types are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) for readability.